import React, {useContext, useState, useEffect} from 'react'
import styled from 'styled-components'
import { Container } from 'react-grid-system'
import Paper from '@material-ui/core/Paper';
import Button from '@material-ui/core/Button';
import {ButtonMostrarTodos, ButtonMostrarMais, BtnAlinhaRecPvt, DivContainerRecursosPublicados, ContainerDivStyled, DivTitulo, StyledP, StyledHR} from './TabPanelMeusRecursos.js'
import axios from 'axios'
import {apiUrl} from '../../env';
import LoadingSpinner from '../LoadingSpinner.js'
import ContainerRedeVazia from './ContainerRedeVazia.js'
import {NoPubSpan, DivConteudoNaoPublicado, DivTextoNoPublications} from './TabPanelMeusRecursos.js'

export default function TabPanelRede (props) {
    const [loading, handleLoading] = useState(true)

    const [followingList, setFollowing] = useState([])
    const [followingListLength, setFollowingLength] = useState(0)

    const [followersList, setFollowers] = useState([])
    const [followersListLength, setFollowersLength] = useState(0)

    useEffect( () => {
        axios.all([
            axios.get((`${apiUrl}/users/` + props.id + '/following/User'), props.config),
            axios.get((`${apiUrl}/users/` + props.id + '/followers'), props.config)
        ])
        .then( (responseArr) => {
                handleLoading(false)
                console.log(responseArr)
                console.log(responseArr[0].data)
                console.log(responseArr[1].data)


            },
            (error) => {
                handleLoading(false)
                console.log('error while running axios all')
            }
        )
    }, [])

    return (
        <>
        {
            loading ?
            (
                [
                    <LoadingSpinner text={'CARREGANDO...'}/>
                ]
            )
            :
            (
                [
                    <>
                    {
                        followingListLength == 0 && followersListLength == 0 ?
                        (
                            [
                                <>
                                    <ContainerRedeVazia/>
                                </>
                            ]
                        )
                        :
                        (
                            [
                                <React.Fragment>
                                    <ContainerDivStyled>
                                        <Paper elevation={3}>
                                                <DivTitulo>
                                                    <StyledP>Seguidor <b style={{fontWeight:"700", fontSize:"20px"}}>({followingListLength})</b></StyledP>
                                                    <StyledHR/>
                                                </DivTitulo>
                                                <div style={{height : "400px"}}>
                                                {
                                                    followingListLength == 0 ?
                                                    (
                                                        [
                                                            <>
                                                                <DivTextoNoPublications>
                                                                    <DivConteudoNaoPublicado>
                                                                        <NoPubSpan>Você não possui nenhum seguidor.</NoPubSpan>
                                                                    </DivConteudoNaoPublicado>
                                                                </DivTextoNoPublications>
                                                            </>
                                                        ]
                                                    )
                                                    :
                                                    (
                                                        [
                                                            <>
                                                                <DivContainerRecursosPublicados/>
                                                                <BtnAlinhaRecPvt>
                                                                    <p style={{margin:"0 0 10px", fontSize:"14px"}}>Carregado 1 de 1</p>
                                                                </BtnAlinhaRecPvt>
                                                            </>
                                                        ]
                                                    )
                                                }
                                                </div>
                                        </Paper>
                                    </ContainerDivStyled>

                                    <ContainerDivStyled>
                                        <Paper elevation={3}>
                                                <DivTitulo>
                                                    <StyledP>Seguindo <b style={{fontWeight:"700", fontSize:"20px"}}>({followersListLength})</b></StyledP>
                                                    <StyledHR/>
                                                </DivTitulo>
                                                <div style={{height : "400px"}}>
                                                {
                                                    followersListLength == 0 ?
                                                    (
                                                        [
                                                            <>
                                                                <DivTextoNoPublications>
                                                                    <DivConteudoNaoPublicado>
                                                                        <NoPubSpan>Você ainda não segue nenhum outro usuário.</NoPubSpan>
                                                                    </DivConteudoNaoPublicado>
                                                                </DivTextoNoPublications>
                                                            </>
                                                        ]
                                                    )
                                                    :
                                                    (
                                                        [
                                                            <>
                                                                <DivContainerRecursosPublicados/>
                                                                <BtnAlinhaRecPvt>
                                                                    <p style={{margin:"0 0 10px", fontSize:"14px"}}>Carregado 1 de 1</p>
                                                                </BtnAlinhaRecPvt>
                                                            </>
                                                        ]
                                                    )
                                                }
                                                </div>
                                        </Paper>
                                    </ContainerDivStyled>
                                </React.Fragment>
                            ]
                        )
                    }
                    </>
                ]
            )
        }
        </>
    )
}
